@@ -1105,7 +1105,7 @@ class XpraClient(XpraClientBase, gobject.GObject):
 
     def _screen_size_changed(self, *args):
         def update_size(current=None):
-            root_w, root_h = self.get_root_size()
+            root_w, root_h = get_root_size()
             ss = self.get_screen_sizes()
             log("update_size(%s) sizes=%s", current, ss)
             if current is not None and current==ss:
@@ -1118,7 +1118,7 @@ class XpraClient(XpraClientBase, gobject.GObject):
             #check again soon:
             gobject.timeout_add(1000, update_size, ss)
         #update via idle_add so the data is actually up to date when we query it!
-        self.idle_add(update_size)
+        gobject.idle_add(update_size)
 
     def get_screen_sizes(self):
         screen_sizes = []
