@@ -63,6 +63,7 @@ class XpraClientBase(gobject.GObject):
         self.min_quality = opts.min_quality
         self.speed = opts.speed
         self.min_speed = opts.min_speed
+        self.pings = opts.pings
         #protocol stuff:
         self._protocol = None
         self._priority_packets = []
@@ -315,6 +316,7 @@ class XpraClientBase(gobject.GObject):
     def parse_server_capabilities(self, capabilities):
         self._remote_version = capabilities.get("version")
         self._remote_revision = capabilities.get("revision")
+        self._remote_revision = capabilities.get("build.revision", self._remote_revision)
         if not is_compatible_with(self._remote_version):
             self.warn_and_quit(EXIT_INCOMPATIBLE_VERSION, "incompatible remote version: %s" % self._remote_version)
             return False
@@ -325,6 +327,10 @@ class XpraClientBase(gobject.GObject):
             self.set_server_encryption(capabilities)
         self._protocol.chunked_compression = capabilities.get("chunked_compression", False)
         self._protocol.aliases = capabilities.get("aliases", {})
+        if self.pings:
+            gobject.timeout_add(1000, self.send_ping)
+        else:
+            gobject.timeout_add(10*1000, self.send_ping)
         return True
 
     def _process_set_deflate(self, packet):
