@@ -10,6 +10,7 @@ import pango
 import gobject
 
 from xpra.deque import maxdeque
+from xpra.platform import get_icon, init
 
 
 modifier_names = {
@@ -47,13 +48,13 @@ class KeyboardStateInfoWindow:
 		label = gtk.Label("Keyboard State")
 		label.modify_font(pango.FontDescription("sans 13"))
 		vbox.pack_start(label)
-		
+
 		self.modifiers = gtk.Label()
 		vbox.add(self.modifiers)
 
 		self.mouse = gtk.Label()
 		vbox.add(self.mouse)
-		
+
 		self.keys = gtk.Label()
 		fixed = pango.FontDescription('monospace 9')
 		self.keys.modify_font(fixed)
@@ -68,6 +69,10 @@ class KeyboardStateInfoWindow:
 		self.window.connect("key-release-event", self.key_release)
 		self.window.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.HAND2))
 
+		icon = get_icon("keyboard.png")
+		if icon:
+			self.window.set_icon(icon)
+
 	def populate_modifiers(self, *args):
 		(x, y, current_mask) = gtk.gdk.get_default_root_window().get_pointer()
 		self.mouse.set_text("%s %s" % (x, y))
@@ -106,10 +111,20 @@ class KeyboardStateInfoWindow:
 	def destroy(self, *args):
 		gtk.main_quit()
 
+
 def main():
+	from xpra.gtk_util import set_application_name, set_prgname
+	if sys.platform.startswith("win"):
+		from xpra.win32 import set_redirect_output, set_log_filename
+		set_redirect_output(True)
+		set_log_filename("Keyboard_Test.log")
+	init()
+	set_prgname("Keyboard Test Tool")
+	set_application_name("Keyboard Test Tool")
 	KeyboardStateInfoWindow()
 	gtk.main()
 
+
 if __name__ == "__main__":
 	main()
 	sys.exit(0)
