@@ -398,12 +398,10 @@ def main(script_file, cmdline):
         signal.signal(signal.SIGUSR1, sigusr1)
         signal.signal(signal.SIGUSR2, sigusr2)
 
-    if (mode in ("start", "upgrade") and supports_server) or \
-        (mode=="shadow" and supports_shadow):
-        if len(args)>0 and mode=="start":
-            #ie: "xpra start ssh:HOST:DISPLAY --start-child=xterm"
-            if args[0].startswith("ssh/") or args[0].startswith("ssh:"):
-                return run_remote_server(parser, options, args)
+    if mode=="start" and len(args)>0 and (args[0].startswith("ssh/") or args[0].startswith("ssh:")):
+        #ie: "xpra start ssh:HOST:DISPLAY --start-child=xterm"
+        return run_remote_server(parser, options, args)
+    elif (mode in ("start", "upgrade") and supports_server) or (mode=="shadow" and supports_shadow):
         nox()
         from xpra.scripts.server import run_server
         return run_server(parser, options, mode, script_file, args)
