@@ -498,7 +498,7 @@ class WindowSource(object):
         info[prefix+"encoding"+suffix] = self.encoding
         self.statistics.add_stats(info, prefix, suffix)
         #batch stats:
-        if len(self.batch_config.last_actual_delays)>0:
+        if len(self.batch_config.last_delays)>0:
             batch_delays = [x for _,x in list(self.batch_config.last_delays)]
             add_list_stats(info, prefix+"batch_delay"+suffix, batch_delays, show_percentile=[9])
         try:
@@ -835,10 +835,13 @@ class WindowSource(object):
         if not window.is_managed():
             return
         ww, wh = window.get_dimensions()
-        if actual_quality>=AUTO_REFRESH_THRESHOLD and w*h>=ww*wh:
-            debug("schedule_auto_refresh: high quality (%s%%) full frame (%s pixels), cancelling refresh timer %s", actual_quality, w*h, self.refresh_timer)
-            #got enough pixels at high quality, cancel timer:
-            self.cancel_refresh_timer()
+        if actual_quality>=AUTO_REFRESH_THRESHOLD:
+            if w*h>=ww*wh:
+                debug("schedule_auto_refresh: high quality (%s%%) full frame (%s pixels), cancelling refresh timer %s", actual_quality, w*h, self.refresh_timer)
+                #got enough pixels at high quality, cancel timer:
+                self.cancel_refresh_timer()
+            else:
+                debug("schedule_auto_refresh: high quality (%s%%) small area, ignoring", actual_quality)
             return
         def full_quality_refresh():
             debug("full_quality_refresh() for %sx%s window", w, h)
@@ -1021,7 +1024,7 @@ class WindowSource(object):
 
     def PIL_encode(self, w, h, coding, data, rowstride, options):
         assert coding in ENCODINGS
-        import Image
+        from PIL import Image
         im = Image.fromstring("RGB", (w, h), data, "raw", "RGB", rowstride)
         buf = StringIO()
         client_options = {}
